@@ -10,7 +10,7 @@
 #'
 #' @section API Documentation:
 #'
-#' [fred/series/release](https://research.stlouisfed.org/docs/api/fred/series_release.html)
+#' [fred/series/release](https://fred.stlouisfed.org/docs/api/fred/series_release.html)
 #'
 #' @seealso [fredr_series_observations()], [fredr_series_search_text()],
 #' [fredr_series_search_id()], [fredr_series_search_tags()],
@@ -19,21 +19,22 @@
 #' [fredr_series_vintagedates()].
 #'
 #' @examples
-#' \donttest{
+#' if (fredr_has_key()) {
 #' # Get release information for the "UNRATE" series
 #' fredr_series_release(series_id = "UNRATE")
 #' }
 #' @export
-fredr_series_release <- function(series_id = NULL,
+fredr_series_release <- function(series_id,
+                                 ...,
                                  realtime_start = NULL,
                                  realtime_end = NULL) {
-
-  validate_series_id(series_id)
+  check_dots_empty(...)
+  check_not_null(series_id, "series_id")
 
   user_args <- capture_args(
-    series_id,
-    realtime_start,
-    realtime_end
+    series_id = series_id,
+    realtime_start = realtime_start,
+    realtime_end = realtime_end
   )
 
   fredr_args <- list(
@@ -41,5 +42,4 @@ fredr_series_release <- function(series_id = NULL,
   )
 
   do.call(fredr_request, c(fredr_args, user_args))
-
 }
